Class: Date

Inherits:
Object
  • Object
show all
Defined in:
lib/sixarm_ruby_date_age.rb

Instance Method Summary collapse

Instance Method Details

#age_in_days(compare_date = Date.today) ⇒ Integer Also known as: age_in_days_on

Returns the age in days for a given date.

Examples:


date=Date.new(1980,10,31)
date.age_in_days => 11124

of custom dates


date=Date.new(1980,10,31)

valentines = Date.new(2011,02,14)
date.age_in_days(valentines) => 11063

halloween = Date.new(2011,10,31)
date.age_in_days(halloween) => 11322

new_years_eve = Date.new(2011,12,31)
date.age_in_days(new_years_eve) => 11383

Returns:

  • (Integer)

    the age in days for a given date.



30
31
32
33
# File 'lib/sixarm_ruby_date_age.rb', line 30

def age_in_days(compare_date = Date.today)
  (compare_date.is_a? Date) or raise ArgumentError, "compare_date must be a date"
  (compare_date - self).to_i
end

#age_in_years(compare_date = Date.today) ⇒ Integer Also known as: age_in_years_on

Returns the age in years for a given date.

Examples:


y = Date.today.year
m = Date.today.month
d = Date.today.mday
date = Date.new(y - 30, m, day)
date.age_in_years => 30

of custom dates


date=Date.new(1980,10,31)

valentines = Date.new(2011,02,14)
date.age_in_years_on(valentines) => 30  # before the birthday

halloween = Date.new(2011,10,31)
date.age_in_years_on(halloween) => 31  # on the birthday is one year older

new_years_eve = Date.new(2011,12,31)
date.age_years(new_years_eve) => 31  # after the birthday is one year older

Returns:

  • (Integer)

    the age in years for a given date.



61
62
63
64
65
66
67
68
# File 'lib/sixarm_ruby_date_age.rb', line 61

def age_in_years(compare_date = Date.today)
  (compare_date.is_a? Date) or raise ArgumentError, "compare_date must be a date"
  return 0 if self == compare_date
  age = compare_date.year - self.year
  min, max = [self, compare_date].sort
  age -= 1 if max.month < min.month or (max.month == min.month and max.day < min.day)
  age
end